#!/usr/bin/perl

# Copyright (C) 2011-2012  Simon Ruderich
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


use strict;
use warnings;


if (scalar @ARGV != 1 and (scalar @ARGV != 2 or not $ARGV[0] =~ /-[st]/)) {
    print STDERR "Usage: $0 [-s | -t] <path/to/device>\n";
    print STDERR "\n";
    print STDERR "Normally this is /sys/devices/platform/*.\n";
    exit 1;
}
if (scalar @ARGV == 1) {
    @ARGV = ('', $ARGV[0]);
}

my $temperature_path = "$ARGV[1]/temp1_input";
my $critical_path    = "$ARGV[1]/temp1_crit";

# No temperature information available.
if (not -e $temperature_path or not -e $critical_path) {
    print STDERR "'$temperature_path' or '$critical_path' not found.\n";
    exit 1;
}

my $screen_mode = ($ARGV[0] eq '-s');
my $tmux_mode   = ($ARGV[0] eq '-t');

my $temperature;
my $critical;

my $file;
open $file, '<', $temperature_path or die $!;
$temperature = <$file>;
close $file or die $!;
open $file, '<', $critical_path or die $!;
$critical = <$file>;
close $file or die $!;

my $value = int($temperature / 1000);
my $risk  = ($critical - $temperature)/$critical;

$value .= "\xb0"; # degree symbol in UTF-8

# GNU screen mode with colors.
if ($screen_mode) {
    my $color;
    if ($risk < 0) {
        $color = 'br r'; # bold reverse
    } elsif ($risk < 0.1) {
        $color = 'b r';
    } elsif ($risk < 0.2) {
        $color = 'b y';
    } else {
        $color = 'b g';
    }

    print "\005{+$color}$value\005{-}\n";

# Same in tmux mode.
} elsif ($tmux_mode) {
    my $color;
    my $style = 'bold';
    if ($risk < 0) {
        $color = 'red';
        $style = 'reverse'; # blink doesn't work for me
    } elsif ($risk < 0.1) {
        $color = 'red';
    } elsif ($risk < 0.2) {
        $color = 'yellow';
    } else {
        $color = 'green';
    }

    print "#[fg=$color,$style]$value#[default]\n";

# Plain text output.
} else {
    print "$value\n";
}
